@@ -6,6 +6,8 @@ def require_auth(roles=None):
     def decorator(f):
         @wraps(f)
         def decorated(*args, **kwargs):
+            if request.method == 'OPTIONS':
+                return f(*args, **kwargs)
             try:
                 # Get the require_auth decorator from AuthManager
                 user = current_app.auth_manager.get_current_user()
